Session transcripts and recording.
This module provides functionality for recording and playing back terminal sessions, with support for the asciicast v2 format.
Re-exports
pub use asciicast::AsciicastHeader;pub use asciicast::read_asciicast;pub use asciicast::write_asciicast;pub use format::EventType;pub use format::Transcript;pub use format::TranscriptEvent;pub use format::TranscriptMetadata;pub use player::PlaybackOptions;pub use player::PlaybackSpeed;pub use player::Player;pub use player::PlayerState;pub use player::play_to_stdout;pub use recorder::Recorder;pub use recorder::RecorderBuilder;