ProcessExitStatus

Enum ProcessExitStatus 

pub enum ProcessExitStatus {
    Exited(i32),
    Signaled(i32),
    Unknown,
}
Exit status of a process.

Variants



Exited(i32)

Process exited with a code.



Signaled(i32)

Process was terminated by a signal (Unix).



Unknown

Exit status is unknown.

Implementations

Source

impl ProcessExitStatus

pub const fn success(self) -> bool

Check if the process exited successfully (code 0).

pub const fn code(self) -> Option<i32>

Get the exit code if the process exited normally.

pub const fn signal(self) -> Option<i32>

Get the signal number if the process was signaled.