RingBuffer

Struct RingBuffer 

pub struct RingBuffer { /* private fields */ }
A circular ring buffer for streaming data.

When the buffer is full, oldest data is overwritten.

Implementations

Source

impl RingBuffer

pub fn new(capacity: usize) -> Self

Create a new ring buffer with the given capacity.

pub const fn len(&self) -> usize

Get the current length of data in the buffer.

pub const fn is_empty(&self) -> bool

Check if the buffer is empty.

pub const fn is_full(&self) -> bool

Check if the buffer is full.

pub const fn capacity(&self) -> usize

Get the capacity of the buffer.

pub fn write(&mut self, data: &[u8])

Write data to the buffer.

If the buffer is full, oldest data is overwritten.

pub fn read_all(&self) -> Vec<u8>

Read all data from the buffer.

This does not consume the data.

pub fn as_string(&self) -> String

Read as a string (lossy UTF-8 conversion).

pub const fn clear(&mut self)

Clear the buffer.

pub fn tail_bytes(&self, n: usize) -> Vec<u8>

Get the last N bytes from the buffer.