Module validation

Module validation 

Command and argument validation.

This module provides validation functions for commands and arguments to prevent security issues such as command injection.

Structs

ValidationOptions
Validation options for command arguments.

Constants

SHELL_METACHARACTERS
Characters that are potentially dangerous in shell contexts.

Functions

contains_null_byte
Check if a string contains null bytes.
contains_shell_metachar
Check if a string contains shell metacharacters.
find_shell_metachar
Find the first shell metacharacter in a string.
validate_argument
Validate a command argument.
validate_command
Validate a command string.
validate_command_with_args
Validate a command and all its arguments.