Common types for rust-expect.
This module defines core types used throughout the library including patterns, matches, and session state.
Structs
- Dimensions
- Terminal dimensions.
- Match
- A match result from an expect operation.
- Session
Id - A unique identifier for a session.
Enums
- Control
Char - Control characters that can be sent to a terminal.
- Expect
Result - Result of an expect operation with multiple patterns.
- Process
Exit Status - Exit status of a process.
- Session
State - The state of a session.