pub struct SpillBuffer { /* private fields */ }Expand description
A buffer that can spill to disk for very large data sets.
Starts in memory and automatically spills to disk when the spill threshold is exceeded.
Implementations
Sourceimpl SpillBuffer
impl SpillBuffer
Sourcepub fn with_config(config: LargeBufferConfig) -> Self
pub fn with_config(config: LargeBufferConfig) -> Self
Create a new spill buffer with custom configuration.
Sourcepub const fn is_spilled(&self) -> bool
pub const fn is_spilled(&self) -> bool
Check if the buffer has spilled to disk.