pub struct VecWriter { /* private fields */ }Expand description
A writer that batches multiple small writes for vectored I/O.
This reduces the number of system calls by accumulating writes and sending them as a single vectored write operation.
Implementations
Sourceimpl VecWriter
impl VecWriter
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Create a vectored writer with the specified chunk capacity.
Sourcepub fn push_slice(&mut self, data: &[u8])
pub fn push_slice(&mut self, data: &[u8])
Add a slice to the writer (copies into a new Bytes).
Sourcepub const fn chunk_count(&self) -> usize
pub const fn chunk_count(&self) -> usize
Get the number of chunks.
Sourcepub fn as_io_slices(&self) -> Vec<IoSlice<'_>>
pub fn as_io_slices(&self) -> Vec<IoSlice<'_>>
Get the chunks as I/O slices for vectored writes.
The returned slices can be passed to write_vectored.