Command and argument validation.
This module provides validation functions for commands and arguments to prevent security issues such as command injection.
Structs
- Validation
Options - Validation options for command arguments.
Constants
- SHELL_
METACHARACTERS - Characters that are potentially dangerous in shell contexts.
Functions
- contains_
null_ byte - Check if a string contains null bytes.
- contains_
shell_ metachar - Check if a string contains shell metacharacters.
- find_
shell_ metachar - Find the first shell metacharacter in a string.
- validate_
argument - Validate a command argument.
- validate_
command - Validate a command string.
- validate_
command_ with_ args - Validate a command and all its arguments.